@@ -2,7 +2,7 @@ package RDF::Helper::Object;
 use strict;
 use warnings;
 use Data::Dumper;
-use Data::Uniqid;
+use Data::UUID;
 use RDF::Helper::TiedPropertyHash;
 use vars qw( $AUTOLOAD );
 use overload
@@ -15,26 +15,49 @@ use overload
 
 =head1 NAME
 
-RDF::Helper::Object - Perl extension for blah blah blah
+RDF::Helper::Object - Perl extension to use RDF property names as methods
 
 =head1 SYNOPSIS
 
   use RDF::Helper;
   my $rdf = RDF::Helper->new(
-      BaseInterface => 'RDF::Redland',
-      Namespaces => { 
-        dc => 'http://purl.org/dc/elements/1.1/',
+      BaseInterface => 'RDF::Trine',
+      namespaces => { 
+        dc => 'http://purl.org/dc/terms/',
         rdf => "http://www.w3.org/1999/02/22-rdf-syntax-ns#",
-        '#default' => "http://purl.org/rss/1.0/"
+        '#default' => "http://xmlns.com/foaf/0.1/"
      }
   );
-  my $obj = $rdf->get_object('http://use.perl.org/');
-  $obj->rdf_type("http://purl.org/rss/1.0/channel");
-  $obj->title("RSS Channel");
-  $obj->description("The description of this RSS feed");
+  my $obj = $rdf->get_object('http://dahut.pm.org/dahut_group.rdf#bender');
+  $obj->rdf_type('http://xmlns.com/foaf/0.1/Person');
+  $obj->name("Bender");
+  $obj->dc_description("A description of Bender");
+  print $rdf->serialize(format => 'rdfxml')
 
 =head1 DESCRIPTION
 
+An object of this class is returned by the L<RDF::Helper>
+C<get_object> method, which takes a B<subject> URI as the first
+argument, and optionally a hash or hashref of options as the second
+argument.
+
+On this object, you may then call methods that correspond to property
+names of the properties you want to get or set.
+
+For properties in the default namespace, you may use them without any
+regard to prefixes, whereas with properties in other namespaces, you
+need to use the prefix and an underscore before the property name.
+
+This class does not make any attempt to verify whether the methods are
+actually valid properties within the used schema, it just blindly does
+what you tell it to. It is suitable for creating relatively simple RDF.
+
+To set more than one object, use an arrayref as argument, e.g.
+
+  $obj->rdfs_label(['Foo', 'Bar'])
+
+will result in two triples, one for each C<rdfs:label>.
+
 =cut
 
 sub new {
@@ -51,10 +74,13 @@ sub new {
 
     my $self = {};
     $self->{_datastore_} = $args{RDFHelper};
+    my $ug    = new Data::UUID;
+    my $uuid = $ug->create();
+
+    $self->{_uri_} = $args{ResourceURI} || "urn:" . $ug->to_string( $uuid );
 
-    $self->{_uri_} = $args{ResourceURI} || "urn:" . Data::Uniqid::uniqid;
     $self->{_rdftype_} = $args{RDFType};
-    $self->{_defaultns_} = $args{DefaultNS} || $self->{_datastore_}->{Namespaces}->{'#default'};
+    $self->{_defaultns_} = $args{DefaultNS} || $self->{_datastore_}->namespaces->{'#default'} || '';
         
     if ( defined( $args{NoTie} ) and $args{NoTie} == 1 ) {
         $self->{_data_} = $self->{_datastore_}->property_hash(
@@ -171,8 +197,8 @@ sub AUTOLOAD {
     if ($attr =~ /^([^_]+)_(.+)$/) {
         my $nsprefix = $1;
         my $nsattr = $2;
-        if ($self->{_datastore_}->{Namespaces}->{$nsprefix}) {
-            $ns = $self->{_datastore_}->{Namespaces}->{$nsprefix};
+        if ($self->{_datastore_}->namespaces->{$nsprefix}) {
+            $ns = $self->{_datastore_}->namespaces->{$nsprefix};
             $attr = $nsprefix . ':' . $nsattr;
             $attr_uri = $ns . $nsattr;
         }
