@@ -40,7 +40,7 @@ has _NS => ( isa => 'HashRef', is => 'ro', );
 
 has ExpandQNames => ( isa => 'Bool', is => 'ro' );
 
-with qw(RDF::Helper::API  RDF::Helper::PerlConvenience);
+with (qw(RDF::Helper::API  RDF::Helper::PerlConvenience));
 
 has base_uri => (
     isa     => 'Str',
@@ -122,7 +122,7 @@ sub add_statement {
     my $statement = shift;
 
     my @nodes = ();
-    foreach my $type qw( subject predicate object ) {
+    foreach my $type (qw( subject predicate object ) ){
         push @nodes, $self->helper2native( $statement->$type );
     }
     $self->model->add_statement( RDF::Trine::Statement->new(@nodes) );
@@ -136,7 +136,7 @@ sub remove_statements {
     my $e = $self->get_enumerator(@_);
     while ( my $s = $e->next ) {
         my @nodes = ();
-        foreach my $type qw( subject predicate object ) {
+        foreach my $type (qw( subject predicate object )) {
             push @nodes, $self->helper2native( $s->$type );
         }
 
@@ -284,7 +284,7 @@ sub next {
 
     my $s     = undef;
     my @nodes = ();
-    foreach my $type qw( subject predicate object ) {
+    foreach my $type (qw( subject predicate object )) {
         push @nodes, process_node( $in->$type );
     }
     return RDF::Helper::Statement->new(@nodes);
